Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(33)

Unified Diff: pkg/analyzer/lib/src/summary/summarize_const_expr.dart

Issue 1610003002: Rename UnlinkedTypeRef to TypeRef. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/summary/summarize_const_expr.dart
diff --git a/pkg/analyzer/lib/src/summary/summarize_const_expr.dart b/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
index 22c92c56a60ccc3929511bb1316fd542b8bb4608..a6713594078d6164bb496413954281e874a76136 100644
--- a/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
+++ b/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
@@ -36,7 +36,7 @@ abstract class AbstractConstExprSerializer {
/**
* See [UnlinkedConstBuilder.references].
*/
- final List<UnlinkedTypeRefBuilder> references = <UnlinkedTypeRefBuilder>[];
+ final List<TypeRefBuilder> references = <TypeRefBuilder>[];
/**
* Serialize the given [expr] expression into this serializer state.
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
}
/**
* Return [UnlinkedTypeRefBuilder] that corresponds to the given [identifier].
*/
- UnlinkedTypeRefBuilder serializeIdentifier(Identifier identifier);
+ TypeRefBuilder serializeIdentifier(Identifier identifier);
/**
* Return [UnlinkedTypeRefBuilder] that corresponds to the given [type].
*/
- UnlinkedTypeRefBuilder serializeType(TypeName type);
+ TypeRefBuilder serializeType(TypeName type);
/**
* Return the [UnlinkedConstBuilder] that corresponds to the state of this
« no previous file with comments | « pkg/analyzer/lib/src/summary/summarize_ast.dart ('k') | pkg/analyzer/lib/src/summary/summarize_elements.dart » ('j') | no next file with comments »
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
}
/**
- * Return [UnlinkedTypeRefBuilder] that corresponds to the given [identifier].
+ * Return [TypeRefBuilder] that corresponds to the given [identifier].
*/
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
/**
- * Return [UnlinkedTypeRefBuilder] that corresponds to the given [type].
+ * Return [TypeRefBuilder] that corresponds to the given [type].
*/

Powered by Google App Engine
This is Rietveld 408576698